@@ -23,7 +23,17 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 	include.h
 */
 
+
+/* whether to use prototypes or not */
+#ifdef __STDC__
+#define P__(x) x
+#else
+#define P__(x)
+#endif
+
+
 #include "options.h"
+#include "gclincl.h"
 #include "config.h"
 
 #ifdef __GNUC__
@@ -43,6 +53,10 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #define EXTER extern 
 #endif
 
+#if defined(GMP) || defined(NEED_MP_H)
+#include "../h/mp.h"
+#endif
+
 #include "../h/compbas.h"
 #include "../h/enum.h"
 #include "../h/object.h"
@@ -52,9 +66,6 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #include "../h/stacks.h"
 #include "../h/lex.h"
 #include "../h/eval.h"
-#ifdef NEED_MP_H
-#include "../h/mp.h"
-#endif
 
 #include "../h/notcomp.h"
 #include "../h/funlink.h"
